@@ -1585,5 +1585,21 @@ class TestAltGuessings(TestCase):
         self.assertEqual([('cat', [['cat_front', 'cat_front_1'], ['cat_side', 'cat_side_1'], ['cat_top', 'cat_top_1']])], alts)
 
 
+class TestMixerGetAtlas(TestCase):
+    @patch('httplib2.Http.request')
+    def test_named_href(self, mock_request):
+        data = '{"terrain.png": null}'
+        mock_request.return_value = ({
+            'status': '200',
+            'content-type': 'application/json',
+            'content-length': str(len(data)),
+        }, data)
+
+        mixer = Mixer()
+        atlas = mixer.get_atlas('http://example.com/mapmap/mapittymap.tpmaps', 'http://example.com/zuer/')
+        self.assertEqual('http://example.com/mapmap/mapittymap.tpmaps', mock_request.call_args[0][0])
+
+
+
 if __name__ == '__main__':
 	unittest.main()
